@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from media_platform.metadata.audio.audio_basic import AudioBasic
 from media_platform.metadata.audio.audio_extra import AudioExtra
 from media_platform.metadata.file_metadata import FileMetadata, MediaType
@@ -5,15 +7,13 @@ from media_platform.service.file_descriptor import FileDescriptor
 
 
 class AudioFileMetadata(FileMetadata):
-    def __init__(self, file_descriptor, basic=None, extra=None):
-        # type: (FileDescriptor, AudioBasic, AudioExtra) -> None
-        super(AudioFileMetadata, self).__init__(MediaType.audio, file_descriptor, basic)
+    def __init__(self, file_descriptor: FileDescriptor, basic: AudioBasic = None, extra: AudioExtra = None):
+        super().__init__(MediaType.audio, file_descriptor, basic)
 
         self.extra = extra
 
     @classmethod
-    def deserialize(cls, data):
-        # type: (dict) -> AudioFileMetadata
+    def deserialize(cls, data: dict) -> AudioFileMetadata:
         if data['mediaType'] != MediaType.audio:
             raise ValueError('not audio metadata')
 
